StructuredPruner

Struct StructuredPruner 

pub struct StructuredPruner {
    pub target_sparsity: f32,
    pub granularity: PruneGranularity,
}
Removes structural units based on L2 norm importance.

Each unit (channel / filter / head) receives a scalar importance score equal to the L2 norm of its weights. The bottom target_sparsity fraction of units are pruned.

Fields

target_sparsity: f32

Fraction of structural units to prune ∈ [0, 1).

granularity: PruneGranularity

Structural granularity.

Implementations

Source

impl StructuredPruner

pub fn new(target_sparsity: f32, granularity: PruneGranularity) -> Self

Create a new structured pruner.

Panics

Panics if target_sparsity is not in [0, 1).

pub fn compute_mask(&self, weights: &[f32]) -> QuantResult<SparseMask>

Compute the pruning mask for weights.

Returns a flat mask the same length as weights.

Errors
pub fn prune(&self, weights: &mut [f32]) -> QuantResult<SparseMask>

Apply structured pruning in-place.

Returns the mask applied.

Errors

Propagates errors from compute_mask.

pub fn unit_l2_norms( weights: &[f32], n_units: usize, unit_size: usize, ) -> Vec<f32>

Compute per-unit L2 norms for a matrix [n_units, unit_size].

Returns a Vec<f32> of length n_units.

pub fn pruned_unit_indices(norms: &[f32], n_prune: usize) -> Vec<usize>

Return the indices of units to prune, sorted ascending by L2 norm.

Prunes the n_prune units with the smallest L2 norm.